.. _further topics:

Introduction
============

Some specific areas of Iris may require further explanation or a deep dive
into additional detail above and beyond that offered by the
:ref:`User Guide <user_guide_introduction>`.

This section provides a collection of additional material on focused topics
that may be of interest to the more advanced or curious user.

.. hint::

   If you wish further documentation on any specific topics or areas of Iris
   that are missing, then please let us know by raising a `GitHub Documentation Issue`_
   on `SciTools/Iris`_.


* :doc:`metadata`
* :doc:`lenient_metadata`
* :doc:`lenient_maths`


.. _GitHub Documentation Issue: https://github.com/SciTools/iris/issues/new?assignees=&labels=New%3A+Documentation%2C+Type%3A+Documentation&template=documentation.md&title=
.. _SciTools/iris: https://github.com/SciTools/iris
